# DisDial

[![GitHub license](https://img.shields.io/github/license/arpy8/DisDial)](https://github.com/arpy8/DisDial/blob/main/LICENSE)

DisDial is a terminal-based IRC-inspired package that enables users to chat on a single server with everyone. This simple and efficient tool is designed for CLI enthusiasts who prefer a text-based chat experience.

## Installation

To install DisDial, assuming you have pip installed simply run the following command:

```bash
pip install disdial
```

## Usage

Run DisDial from your terminal and start chatting by following these steps:

```bash
disdial
```
On your first launch you'll be asked to type your username, you can change it later on.

### Options
- `-h` or `--help`: Get to know about the arguments.

If you wish to know more about the packge description, run:<br> 
`pip show disdial`

### Commands

- `-c`: Change username.
- `rr`, `rf`, `-r`, `rl`, `clea`, or just press enter: Refresh the screen to check for latest message.
- `exit` or `ctrl+c`: Exit DisDial.

## Documentation

For detailed information and usage examples, refer to the [documentation](https://youtu.be/QwLvrnlfdNo?si=FlP3kmyUCLLcqSXH).

## Contributing

Feel free to contribute to the development of DisDial by submitting issues or pull requests. Your feedback and suggestions are highly appreciated!

## License

This project is licensed under the MIT License - see the [LICENSE](https://github.com/arpy8/DisDial/blob/main/LICENSE) file for details.
